@@ -1,5 +1,3 @@
-import pkg_resources
-
-from crusher.crusher import *
+import pkg_resources  # type: ignore
 
 __version__ = pkg_resources.get_distribution("crusher").version
